# frozen_string_literal: true

module Voucher
  class SegmentsBuilder
    def self.call(data)
      new(data).call
    end

    def initialize(data)
      @data = data
    end

    def call
      build
    end

    private

    def build
      { election: election, segments: segments }
    end

    def election
      attributes = @data.dig(:election, :attributes) || {}

      Election.new(attributes)
    end

    def segments
      raise ArgumentError, 'Segments data must be an array' unless @data[:segments].is_a?(Array)

      @data[:segments].map do |segment|
        Segment.new(segment[:attributes] || {})
      end
    end
  end
end
