# frozen_string_literal: true

module Voucher
  class SegmentsParser
    def self.call(json)
      new(json).call
    end

    def initialize(json)
      @json = json
    end

    def call
      parse
    end

    private

    def parse
      content = segments_from_json

      SegmentsBuilder.call(
        election: content[:included]&.first,
        segments: content[:data]
      )
    end

    def segments_from_json
      parsed_json = JSON.parse(@json)

      underscore_keys(parsed_json).with_indifferent_access
    end

    def underscore_keys(parsed_json)
      parsed_json.deep_transform_keys { |key| key.to_s.underscore }
    end
  end
end
